MmcConfig

Struct MmcConfig 

pub struct MmcConfig { /* private fields */ }
Represents the SD/MMC state-machine.

Implementations

Source

impl MmcConfig

pub const fn new() -> Self

Creates a new MmcConfig.

pub const fn bus_mode(&self) -> BusMode

Gets the BusMode for the MmcConfig.

pub fn set_bus_mode(&mut self, bus_mode: BusMode)

Sets the BusMode for the MmcConfig.

pub const fn with_bus_mode(self, bus_mode: BusMode) -> Self

Builder function that sets the BusMode for the MmcConfig.

pub const fn bus_width(&self) -> BusWidth

Gets the BusWidth for the MmcConfig.

pub fn set_bus_width(&mut self, bus_width: BusWidth)

Sets the BusWidth for the MmcConfig.

pub const fn with_bus_width(self, bus_width: BusWidth) -> Self

Builder function that sets the BusWidth for the MmcConfig.

pub const fn power_mode(&self) -> PowerMode

Gets the PowerMode for the MmcConfig.

pub fn set_power_mode(&mut self, power_mode: PowerMode)

Sets the PowerMode for the MmcConfig.

pub const fn with_power_mode(self, power_mode: PowerMode) -> Self

Builder function that sets the PowerMode for the MmcConfig.

pub const fn timing(&self) -> Timing

Gets the Timing for the MmcConfig.

pub fn set_timing(&mut self, timing: Timing)

Sets the Timing for the MmcConfig.

pub const fn with_timing(self, timing: Timing) -> Self

Builder function that sets the Timing for the MmcConfig.

pub const fn slot(&self) -> usize

Gets the slot for the MmcConfig.

pub fn set_slot(&mut self, slot: usize)

Sets the slot for the MmcConfig.

pub const fn with_slot(self, slot: usize) -> Self

Builder function that sets the slot for the MmcConfig.

pub const fn erase_mode(&self) -> EraseMode

Gets the EraseMode for the MmcConfig.

pub fn set_erase_mode(&mut self, erase_mode: EraseMode)

Sets the EraseMode for the MmcConfig.

pub const fn with_erase_mode(self, erase_mode: EraseMode) -> Self

Builder function that sets the EraseMode for the MmcConfig.

pub const fn address_mode(&self) -> AddressMode

Gets the AddressMode for the MmcConfig.

pub fn set_address_mode(&mut self, address_mode: AddressMode)

Sets the AddressMode for the MmcConfig.

pub const fn with_address_mode(self, address_mode: AddressMode) -> Self

Builder function that sets the AddressMode for the MmcConfig.

pub const fn csd(&self) -> &Csd

Gets a reference to the Csd for the MmcConfig.

pub fn csd_mut(&mut self) -> &mut Csd

Gets a mutable reference to the Csd for the MmcConfig.

pub fn set_csd(&mut self, csd: Csd)

Sets the Csd for the MmcConfig.

pub const fn with_csd(self, csd: Csd) -> Self

Builder function that sets the Csd for the MmcConfig.

pub const fn ext_csd(&self) -> &ExtCsd

Gets a reference to the ExtCsd for the MmcConfig.

pub fn ext_csd_mut(&mut self) -> &mut ExtCsd

Gets a mutable reference to the ExtCsd for the MmcConfig.

pub fn set_ext_csd(&mut self, ext_csd: ExtCsd)

Sets the ExtCsd for the MmcConfig.

pub const fn with_ext_csd(self, ext_csd: ExtCsd) -> Self

Builder function that sets the ExtCsd for the MmcConfig.

pub const fn wp_grp_size(&self) -> u32

Gets the wp_grp_size for the MmcConfig.

pub fn set_wp_grp_size(&mut self)

Sets the wp_grp_size for the MmcConfig.

pub const fn can_discard(&self) -> bool

Gets whether the device supports the DISCARD feature.

pub const fn can_trim(&self) -> bool

Gets whether the device supports the TRIM feature.

pub const fn hs200(&self) -> bool

Gets whether the device is configured for HS200 timing.

pub const fn hs400(&self) -> bool

Gets whether the device is configured for HS400 timing.

pub const fn hs400es(&self) -> bool

Gets whether the device is configured for HS400 timing.

pub const fn erase_size(&self) -> usize

Gets the erase size for the device.

pub fn set_erase_size(&mut self)

Sets the erase size for the device read from the CSD register.