pub struct MmcConfig { /* private fields */ }Expand description
Represents the SD/MMC state-machine.
Implementations
Sourceimpl MmcConfig
impl MmcConfig
Sourcepub fn set_bus_mode(&mut self, bus_mode: BusMode)
pub fn set_bus_mode(&mut self, bus_mode: BusMode)
Sourcepub const fn with_bus_mode(self, bus_mode: BusMode) -> Self
pub const fn with_bus_mode(self, bus_mode: BusMode) -> Self
Sourcepub fn set_bus_width(&mut self, bus_width: BusWidth)
pub fn set_bus_width(&mut self, bus_width: BusWidth)
Sourcepub const fn with_bus_width(self, bus_width: BusWidth) -> Self
pub const fn with_bus_width(self, bus_width: BusWidth) -> Self
Sourcepub const fn power_mode(&self) -> PowerMode
pub const fn power_mode(&self) -> PowerMode
Sourcepub fn set_power_mode(&mut self, power_mode: PowerMode)
pub fn set_power_mode(&mut self, power_mode: PowerMode)
Sourcepub const fn with_power_mode(self, power_mode: PowerMode) -> Self
pub const fn with_power_mode(self, power_mode: PowerMode) -> Self
Sourcepub fn set_timing(&mut self, timing: Timing)
pub fn set_timing(&mut self, timing: Timing)
Sourcepub const fn with_timing(self, timing: Timing) -> Self
pub const fn with_timing(self, timing: Timing) -> Self
Sourcepub const fn with_slot(self, slot: usize) -> Self
pub const fn with_slot(self, slot: usize) -> Self
Builder function that sets the slot for the MmcConfig.
Sourcepub const fn erase_mode(&self) -> EraseMode
pub const fn erase_mode(&self) -> EraseMode
Sourcepub fn set_erase_mode(&mut self, erase_mode: EraseMode)
pub fn set_erase_mode(&mut self, erase_mode: EraseMode)
Sourcepub const fn with_erase_mode(self, erase_mode: EraseMode) -> Self
pub const fn with_erase_mode(self, erase_mode: EraseMode) -> Self
Sourcepub const fn address_mode(&self) -> AddressMode
pub const fn address_mode(&self) -> AddressMode
Gets the AddressMode for the MmcConfig.
Sourcepub fn set_address_mode(&mut self, address_mode: AddressMode)
pub fn set_address_mode(&mut self, address_mode: AddressMode)
Sets the AddressMode for the MmcConfig.
Sourcepub const fn with_address_mode(self, address_mode: AddressMode) -> Self
pub const fn with_address_mode(self, address_mode: AddressMode) -> Self
Builder function that sets the AddressMode for the MmcConfig.
Sourcepub fn ext_csd_mut(&mut self) -> &mut ExtCsd
pub fn ext_csd_mut(&mut self) -> &mut ExtCsd
Sourcepub fn set_ext_csd(&mut self, ext_csd: ExtCsd)
pub fn set_ext_csd(&mut self, ext_csd: ExtCsd)
Sourcepub const fn with_ext_csd(self, ext_csd: ExtCsd) -> Self
pub const fn with_ext_csd(self, ext_csd: ExtCsd) -> Self
Sourcepub const fn wp_grp_size(&self) -> u32
pub const fn wp_grp_size(&self) -> u32
Gets the wp_grp_size for the MmcConfig.
Sourcepub fn set_wp_grp_size(&mut self)
pub fn set_wp_grp_size(&mut self)
Sets the wp_grp_size for the MmcConfig.
Sourcepub const fn can_discard(&self) -> bool
pub const fn can_discard(&self) -> bool
Gets whether the device supports the DISCARD feature.
Sourcepub const fn erase_size(&self) -> usize
pub const fn erase_size(&self) -> usize
Gets the erase size for the device.
Sourcepub fn set_erase_size(&mut self)
pub fn set_erase_size(&mut self)
Sets the erase size for the device read from the CSD register.